summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sw/qa/extras/htmlexport/htmlexport.cxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/sw/qa/extras/htmlexport/htmlexport.cxx b/sw/qa/extras/htmlexport/htmlexport.cxx
index 6342fe769ae7..b492f133dc63 100644
--- a/sw/qa/extras/htmlexport/htmlexport.cxx
+++ b/sw/qa/extras/htmlexport/htmlexport.cxx
@@ -340,8 +340,9 @@ DECLARE_HTMLEXPORT_ROUNDTRIP_TEST(testFdo81276, "fdo81276.html")
CPPUNIT_TEST_FIXTURE(HtmlExportTest, testFdo62336)
{
// The problem was essentially a crash during table export as docx/rtf/html
- // If calc-layout is enabled, the crash does not occur
- loadAndReload("fdo62336.docx");
+ // If calc-layout is enabled, the crash does not occur, that's why loadFromURL/save is used
+ loadFromURL(u"fdo62336.docx");
+ save("HTML (StarWriter)");
}
DECLARE_HTMLEXPORT_ROUNDTRIP_TEST(testFdo86857, "fdo86857.html")